==> vtk7_7.1.1+dfsg2.orig.tar.xz: VTK-7.1.1/Filters/Points/vtkLinearKernel.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkLinearKernel.cxx

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "vtkLinearKernel.h"
#include "vtkAbstractPointLocator.h"
#include "vtkObjectFactory.h"
#include "vtkIdList.h"
#include "vtkDoubleArray.h"

vtkStandardNewMacro(vtkLinearKernel);

//----------------------------------------------------------------------------
vtkLinearKernel::vtkLinearKernel()
{
}


//----------------------------------------------------------------------------
vtkLinearKernel::~vtkLinearKernel()
{
}


//----------------------------------------------------------------------------
vtkIdType vtkLinearKernel::
ComputeWeights(double*, vtkIdList *pIds, vtkDoubleArray *prob,
               vtkDoubleArray *weights)
{
  vtkIdType numPts = pIds->GetNumberOfIds();
  double *p = (prob ? prob->GetPointer(0) : NULL);
  weights->SetNumberOfTuples(numPts);
  double *w = weights->GetPointer(0);
  double weight = 1.0 / static_cast<double>(numPts);

  if ( ! prob ) //standard linear interpolation
  {
    for (vtkIdType i=0; i < numPts; ++i)
    {
      w[i] = weight;
    }
  }

  else //weight by probability
  {
    double sum=0.0;
    for (vtkIdType i=0; i < numPts; ++i)
    {
      w[i] = weight * p[i];
      sum += w[i];
    }
    // Now normalize
    if ( this->NormalizeWeights && sum != 0.0 )
    {
      for (vtkIdType i=0; i < numPts; ++i)
      {
        w[i] /= sum;
      }
    }
  }

  return numPts;
}

//----------------------------------------------------------------------------
void vtkLinearKernel::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os,indent);
}

==> vtk9_9.0.1+dfsg1.orig.tar.xz: VTK-9.0.1/Filters/Points/vtkLinearKernel.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkLinearKernel.cxx

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
#include "vtkLinearKernel.h"
#include "vtkAbstractPointLocator.h"
#include "vtkDoubleArray.h"
#include "vtkIdList.h"
#include "vtkObjectFactory.h"

vtkStandardNewMacro(vtkLinearKernel);

//----------------------------------------------------------------------------
vtkLinearKernel::vtkLinearKernel() = default;

//----------------------------------------------------------------------------
vtkLinearKernel::~vtkLinearKernel() = default;

//----------------------------------------------------------------------------
vtkIdType vtkLinearKernel::ComputeWeights(
  double*, vtkIdList* pIds, vtkDoubleArray* prob, vtkDoubleArray* weights)
{
  vtkIdType numPts = pIds->GetNumberOfIds();
  double* p = (prob ? prob->GetPointer(0) : nullptr);
  weights->SetNumberOfTuples(numPts);
  double* w = weights->GetPointer(0);
  double weight = 1.0 / static_cast<double>(numPts);

  if (!prob) // standard linear interpolation
  {
    for (vtkIdType i = 0; i < numPts; ++i)
    {
      w[i] = weight;
    }
  }

  else // weight by probability
  {
    double sum = 0.0;
    for (vtkIdType i = 0; i < numPts; ++i)
    {
      w[i] = weight * p[i];
      sum += w[i];
    }
    // Now normalize
    if (this->NormalizeWeights && sum != 0.0)
    {
      for (vtkIdType i = 0; i < numPts; ++i)
      {
        w[i] /= sum;
      }
    }
  }

  return numPts;
}

//----------------------------------------------------------------------------
void vtkLinearKernel::PrintSelf(ostream& os, vtkIndent indent)
{
  this->Superclass::PrintSelf(os, indent);
}
